@@ -123,7 +123,7 @@ public final class TestStAXStreamOutputter extends AbstractTestOutputter {
 	}
     
 	@Override
-	public String outputString(Format format, Document doc) {
+	public String outputDocumentAsString(Format format, Document doc) {
 		OutWrapper ow = new OutWrapper(format);
 		try {
 			ow.getStax().output(doc, ow.getStream());
@@ -135,7 +135,7 @@ public final class TestStAXStreamOutputter extends AbstractTestOutputter {
 	}
 
 	@Override
-	public String outputString(Format format, DocType doctype) {
+	public String outputDocTypeAsString(Format format, DocType doctype) {
 		OutWrapper ow = new OutWrapper(format);
 		try {
 			ow.getStream().writeStartDocument();
@@ -151,7 +151,7 @@ public final class TestStAXStreamOutputter extends AbstractTestOutputter {
 	}
 
 	@Override
-	public String outputString(Format format, Element element) {
+	public String outputElementAsString(Format format, Element element) {
 		OutWrapper ow = new OutWrapper(format);
 		try {
 			ow.getStream().writeStartDocument();
@@ -167,7 +167,7 @@ public final class TestStAXStreamOutputter extends AbstractTestOutputter {
 	}
 
 	@Override
-	public String outputString(Format format, List<? extends Content> list) {
+	public String outputListAsString(Format format, List<? extends Content> list) {
 		OutWrapper ow = new OutWrapper(format);
 		try {
 			ow.getStream().writeStartDocument();
@@ -186,7 +186,7 @@ public final class TestStAXStreamOutputter extends AbstractTestOutputter {
 	}
 
 	@Override
-	public String outputString(Format format, CDATA cdata) {
+	public String outputCDataAsString(Format format, CDATA cdata) {
 		OutWrapper ow = new OutWrapper(format);
 		try {
 			ow.getStream().writeStartDocument();
@@ -205,7 +205,7 @@ public final class TestStAXStreamOutputter extends AbstractTestOutputter {
 	}
 
 	@Override
-	public String outputString(Format format, Text text) {
+	public String outputTextAsString(Format format, Text text) {
 		OutWrapper ow = new OutWrapper(format);
 		try {
 			ow.getStream().writeStartDocument();
@@ -224,7 +224,7 @@ public final class TestStAXStreamOutputter extends AbstractTestOutputter {
 	}
 
 	@Override
-	public String outputString(Format format, Comment comment) {
+	public String outputCommentAsString(Format format, Comment comment) {
 		OutWrapper ow = new OutWrapper(format);
 		try {
 			ow.getStream().writeStartDocument();
@@ -240,7 +240,7 @@ public final class TestStAXStreamOutputter extends AbstractTestOutputter {
 	}
 
 	@Override
-	public String outputString(Format format, ProcessingInstruction pi) {
+	public String outputPIAsString(Format format, ProcessingInstruction pi) {
 		OutWrapper ow = new OutWrapper(format);
 		try {
 			ow.getStream().writeStartDocument();
@@ -256,7 +256,7 @@ public final class TestStAXStreamOutputter extends AbstractTestOutputter {
 	}
 
 	@Override
-	public String outputString(Format format, EntityRef entity) {
+	public String outputEntityRefAsString(Format format, EntityRef entity) {
 		OutWrapper ow = new OutWrapper(format);
 		try {
 			ow.getStream().writeStartDocument();
